@@ -27,17 +27,23 @@ public:
         const char *data = PyUnicode_AsUTF8AndSize(src.ptr(), &size);
         if (data == NULL)
         {
+            PyErr_Clear();
             return false;
         }
 
         // this assumes that the stringref won't be retained after the function call
         value = wpi::StringRef(data, size);
+
+        // src must be valid as long as this loader is valid
+        loader_life_support::add_patient(src);
         return true;
     }
 
     static handle cast(const wpi::StringRef &s, return_value_policy, handle)
     {
-        return PyUnicode_FromStringAndSize(s.data(), s.size());
+        handle h = PyUnicode_FromStringAndSize(s.data(), s.size());
+        if (!h) throw error_already_set();
+        return h;
     }
 };
 
